==> endless_page-6.x-1.0.tar.gz: endless_page/js/endless_page.js <==
// $Id: endless_page.js,v 1.2 2008/11/06 16:14:39 asund Exp $

/**
 * The javascript used by endless_page module for Drupal
 * Module is written by Are Sundnes, 2008
 */

var nodes;
var scrollMargin;
var groupItems;
var teaser;
var nodes;
var loadPage;
var modulePath;
var xmlHttp;
var group = 0;
var item = 0;
var loadingGroup = false;


// inputNodes = Array of nodeID's to load content from.
// inputStartItmes = Number of items to load on page initiation
// inputScrollMargin = Number of pixels from the bottom of the document onw should scroll before loading next group
// inputTeaser = Should the nodes load as teasers or full nodes? Allowed values: 1 and 0.
// inputLoadPage = Complete URL to the loadpage created by the module
// inputModulePath = Complete URL to the endless_page module folder
function init_endless_page(inputNodes,inputStartItems,inputScrollMargin,inputGroupItems,inputTeaser,inputLoadPage,inputModulePath) {

	// Set the variables
	nodes=inputNodes;
	scrollMargin = inputScrollMargin;
	teaser = inputTeaser;
	loadPage = inputLoadPage;
	modulePath = inputModulePath;
	
	// Set groupItems to inputStartItems for loading the first group
	groupItems = inputStartItems; 

	// Load the first group
	endless_page_load(); 
	
	// The first group is loaded, so now set groupItems to inputGroupItems
	groupItems = inputGroupItems; 
		
	// Use jQuery Dimensions to get scrollbar position
	// This function is run each time the user changes the scroll position
	$(document).scroll( function() { 
		// Check if user is scrolled further down than scrollMargin	
		if($(document).scrollTop()>=(($(document).height()-$(window).height())-scrollMargin)) 
			// If scrolled further down than scrollMargin and the script is not allready loading another group and the script is not stopped, load the next group.
			if(!loadingGroup) endless_page_load();	
	} );
}


// Function for loading the next group
function endless_page_load() 
{
	if(!nodes[item]) return;
		// Create the div for the new group
		var newGroup = document.createElement("div"); 
		
		// Set ID to the div
		newGroup.setAttribute("id","endless-group-"+group); 
		
		// Insert the preloader gif
		newGroup.innerHTML="<img src='"+modulePath+"/images/loading.gif'/>"; 

		// Locate the container DIV
		container = document.getElementById("endless_page"); 

		// Insert new group on the end of the container DIV
		document.getElementById("endless_page").parentNode.insertBefore(newGroup,container); 

		// Setting this variable to TRUE will keep the javascript from attempting to load any more nodes. We will unset it once we get the content from this call.
		loadingGroup=true; 

		// Load the xmlHttp object required for using AJAX 
		xmlHttp=GetXmlHttpObject(); 
		if (xmlHttp==null) {
			// If javascript can't get the xmlHttp object, the user will not be able to use this page.
			alert ("Your browser does not support AJAX!"); 
			return;
		} 

	// Start making the URL for the load page
	var url=loadPage; 
	
	// The first argument to the load page is the current item number. This is used to make an unique div id for each item. May be useful.
	url += "/"+item; 

	// Tell the load page to load as teaser or as full page
	url += "/"+teaser; 

	// Loop this for each item in group
	var i = groupItems;	
	while(i>0) {	

		// If there are noe more items, stop the function and don't unset the loadingGroup variable. This means the javascript will not try to load more content.
		if(!nodes[item]) return; 

		// Add the item's nodeID as an argument for the load page.
		url+="/"+nodes[item]; 

		item++;
		i--;
	}

	xmlHttp.onreadystatechange=stateChanged; 
	xmlHttp.open("GET",url,true);
	xmlHttp.send(null);
} 


//xmlHttp state has changed
function stateChanged() 
{ 
	// State is 4 - meaning the content was recieved successfully.
	if (xmlHttp.readyState==4) 
	{ 

		// Set the content of the group now that we got it back from the load page.
		document.getElementById("endless-group-"+group).innerHTML=xmlHttp.responseText; 

		// If there are any more nodes in the array, unset this variable to let javascript know we're finished loading for now and it can run the function again
		if(nodes[item+1]) loadingGroup=false; 
		
		group++;
	}
}


// Standard AJAX function for getting the xmlHttpObject. Different browsers handles this differently - thus the try and catch.
function GetXmlHttpObject() 
{
	var xmlHttp=null;
	try {
	  // Firefox, Opera 8.0+, Safari
	  xmlHttp=new XMLHttpRequest(); }
	catch (e) {
	  // Internet Explorer
	  try { xmlHttp=new ActiveXObject("Msxml2.XMLHTTP"); }
	  catch (e) { xmlHttp=new ActiveXObject("Microsoft.XMLHTTP"); }
	}
	return xmlHttp;
}

==> endless_page-6.x-1.2.tar.gz: endless_page/js/endless_page.js <==
// $Id: endless_page.js,v 1.7 2008/11/09 23:40:32 asund Exp $

/**
 * The javascript used by endless_page module for Drupal
 * Module is written by Are Sundnes, 2008
 */

var scrollMargin;
var groupItems;
var teaser;
var nodes;
var loadPage;
var modulePath;
var xmlHttp;
var group = 0;
var item = 0;
var itemid;
var loadingGroup = false;
var loadingGraphics;

// inputNodes = Array of nodeID's to load content from.
// inputStartItmes = Number of items to load on page initiation
// inputScrollMargin = Number of pixels from the bottom of the document onw should scroll before loading next group
// inputTeaser = Should the nodes load as teasers or full nodes? Allowed values: 1 and 0.
// inputLoadPage = Complete URL to the loadpage created by the module
// inputModulePath = Complete URL to the endless_page module folder
// inputLoadingGraphics = Image to show wile loading
function init_endless_page(inputNodes,inputStartItems,inputScrollMargin,inputGroupItems,inputTeaser,inputLoadPage,inputModulePath,inputLoadingGraphics) {

	// Set the variables
	nodes=inputNodes;
	scrollMargin = inputScrollMargin;
	teaser = inputTeaser;
	loadPage = inputLoadPage;
	modulePath = inputModulePath;
	loadingGraphics = inputLoadingGraphics;	
	
	// Set groupItems to inputStartItems for loading the first group
	itemid = inputStartItems; 

	
	// The first group is loaded, so now set groupItems to inputGroupItems
	groupItems = inputGroupItems; 	
		
	// Use jQuery Dimensions to get scrollbar position
	// This function is run each time the user changes the scroll position
	window.onload = function() {	
		$(document).scroll( function() { 
			// Check if user is scrolled further down than scrollMargin	
			if($(document).scrollTop()>=(($(document).height()-$(window).height())-scrollMargin)) 
				// If scrolled further down than scrollMargin and the script is not allready loading another group and the script is not stopped, load the next group.
				if(!loadingGroup) endless_page_load();	
		} );
		if($(document).scrollTop()>=(($(document).height()-$(window).height())-50)) {
			endless_page_load()
		}
	}
}


// Function for loading the next group
function endless_page_load() 
{
	if(!nodes[item]) return;
		// Create the div for the new group
		var newGroup = document.createElement("div"); 
		
		// Set ID to the div
		newGroup.setAttribute("id","endless-group-"+group); 
		
		// Insert the preloader gif
		newGroup.innerHTML="<img src='"+loadingGraphics+"'/>"; 

		// Locate the container DIV
		container = document.getElementById("endless_page_loaded"); 

		// Insert new group on the end of the container DIV
		document.getElementById("endless_page_loaded").parentNode.insertBefore(newGroup,container); 

		// Setting this variable to TRUE will keep the javascript from attempting to load any more nodes. We will unset it once we get the content from this call.
		loadingGroup=true; 

		// Load the xmlHttp object required for using AJAX 
		xmlHttp=GetXmlHttpObject(); 
		if (xmlHttp==null) {
			// If javascript can't get the xmlHttp object, the user will not be able to use this page.
			alert ("Your browser does not support AJAX!"); 
			return;
		} 

	// Start making the URL for the load page
	var url=loadPage; 
	
	// The first argument to the load page is the current item number. This is used to make an unique div id for each item. May be useful.
	url += "/"+itemid; 

	// Tell the load page to load as teaser or as full page
	url += "/"+teaser; 

	// Loop this for each item in group
	var i = groupItems;	
	while(i>0) {	

		// Add the item's nodeID as an argument for the load page.
		url+="/"+nodes[item]; 

		item++;
		itemid++
		i--;
	}

	xmlHttp.onreadystatechange=stateChanged; 
	xmlHttp.open("GET",url,true);
	xmlHttp.send(null);
} 

// Function for telling the javascript it can start loading new nodes again. If scrolled all the way to the bottom, we will load the next one right away.
function restartFunction() {
	loadingGroup=false; 
	if($(document).scrollTop()>=(($(document).height()-$(window).height())-50)) {
		endless_page_load()
	}	
}


//xmlHttp state has changed
function stateChanged() 
{ 
	// State is 4 - meaning the content was recieved successfully.
	if (xmlHttp.readyState==4) 
	{ 
		// Set the content of the group now that we got it back from the load page.
		document.getElementById("endless-group-"+group).innerHTML=xmlHttp.responseText; 

		// If there are any more nodes in the array, unset this variable to let javascript know we're finished loading for now and it can run the function again, but wait a few seconds, so it wont start loading more nodes right away
		if(nodes[item]) setTimeout('restartFunction()',2000);
		
		group++;
	}
}


// Standard AJAX function for getting the xmlHttpObject. Different browsers handles this differently - thus the try and catch.
function GetXmlHttpObject() 
{
	var xmlHttp=null;
	try {
	  // Firefox, Opera 8.0+, Safari
	  xmlHttp=new XMLHttpRequest(); }
	catch (e) {
	  // Internet Explorer
	  try { xmlHttp=new ActiveXObject("Msxml2.XMLHTTP"); }
	  catch (e) { xmlHttp=new ActiveXObject("Microsoft.XMLHTTP"); }
	}
	return xmlHttp;
}
